@@ -46,7 +46,7 @@ var NAVTREE =
 var NAVTREEINDEX =
 [
 "AdaptorInterfaces_8h.html",
-"structsdbus_1_1signature__of_3_01std_1_1string_01_4.html"
+"structsdbus_1_1signature__of_3_01std_1_1array_3_01__Element_00_01__Size_01_4_01_4.html"
 ];
 
 var SYNCONMSG = 'click to disable panel synchronisation';
